@@ -6,7 +6,7 @@
 # Description:
 
 def text_pre(text: str):
-    text = text.replace("这个月", "本月")
+    text = text.replace("这个月", "本月").replace("这一个月", "本月")
     return text
 
 
